pygeodesy.deprecated.rhumbaux

Package pygeodesy :: Package deprecated :: Module rhumbaux |
[frames] | no frames]

# Module rhumbaux

DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.aux_ instead.

Version: 25.05.12

Classes
| RhumbAux Class to solve the direct and inverse rhumb problems, based on Auxiliary Latitudes for accuracy near the poles.
| RhumbLineAux Compute one or several points on a single rhumb line.

Variables
| __all__ = `_ALL_LAZY.rhumb_aux_`